from Products.Archetypes.public import *
from Products.Archetypes.Marshall import PrimaryFieldMarshaller
from Products.CMFCore import CMFCorePermissions
from config import PROJECTNAME

schema = BaseFolderSchema +  Schema((

    # we overide the default title field with a new label and description
    StringField('title',
        required = 1,
        searchable = 1,
		widget = StringWidget(
			label = 'Product Name',
			description = 'Enter the name of the product'
		),
	),

    StringField('homepage',
		validators='isURL',
		widget = StringWidget(
			label = 'Homepage',
			description = 'The URL where product information is published'
		),
	),

    StringField('contact',
		validators='isEmail',
		widget = StringWidget(
			label = 'Contact eMail address',
			description = 'An email address for contact'
		),
	),

    TextField('product_information',
        required = 1,
        searchable = 1,
		default_content_type = "text/html",
		default_output_type = "text/html",
        allowable_content_types = ("text/plain", "text/html", "text/structured"),
		widget = TextAreaWidget(
			label = 'Product Description',
			description = 'Everything that is noteworthy (description, license...) goes here '
		),
	),
))


class Product(BaseFolder):

    schema = schema

    filter_content_types = 1
    allowed_content_types = ('Release', 'Screenshot')

    actions = ({
        'id': 'view',
        'name': 'View',
        'action': 'string:${object_url}/product_view',
        'permissions': (CMFCorePermissions.View,)
        },
        {'id': 'screenshots',
        'name': 'Screenshots',
        'action': 'string:${object_url}/screenshots_view',
        'permissions': (CMFCorePermissions.View,)
        })

    def listScreenshots(self):
        """ get a list of screenshots
            From: CMFPhotoAlbum"""
        return self.listFolderContents(contentFilter={'Type':('Screenshot',)})

registerType(Product, PROJECTNAME)
